#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_BSEARCH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_BSEARCH_HPP_INCLUDED

#include <nt2/interpol/include/functions/scalar/bsearch.hpp>

#endif
